pub struct RateLimitConfig {
pub enabled: bool,
pub max_requests: u32,
pub window_seconds: u64,
pub strategy: String,
pub trust_proxy: bool,
}Expand description
Rate limiting configuration for Tideway applications
Fields
enabled: boolWhether rate limiting is enabled
max_requests: u32Maximum number of requests allowed per window
window_seconds: u64Time window in seconds for rate limiting
strategy: StringRate limiting strategy: “global” or “per_ip”
trust_proxy: boolTrust X-Forwarded-For header for client IP detection
SECURITY WARNING: Only enable this if your application is behind a trusted reverse proxy (nginx, cloudflare, AWS ALB, etc.).
When false (default): Only uses the direct connection IP, ignoring
proxy headers. This is safe but won’t work correctly behind a proxy.
When true: Trusts X-Forwarded-For and X-Real-IP headers. Only enable
if your proxy is properly configured to overwrite (not append to) these
headers, otherwise attackers can spoof their IP to bypass rate limiting.
Default: false
Implementations
Sourceimpl RateLimitConfig
impl RateLimitConfig
Sourcepub fn builder() -> RateLimitConfigBuilder
pub fn builder() -> RateLimitConfigBuilder
Create a new RateLimitConfig builder
Sourcepub fn permissive() -> Self
pub fn permissive() -> Self
Create a permissive rate limit configuration for development Allows 1000 requests per minute
Sourcepub fn restrictive() -> Self
pub fn restrictive() -> Self
Create a restrictive rate limit configuration for production Default: 100 requests per minute per IP